#!/bin/sh

#
# Copyright (c) 01/05/05 Sun Microsystems, Inc. All Rights Reserved.
#
# ident	"@(#)prj_add.sh	1.4	05/01/05 SMI"
#


#
# This script creates a project as part of the container creation
#

#
# The return values or the exit values for all the scripts should 
# be of the following:
#
# exit_status	meaning
#	0	command successfull
#	1	Usage error
#	2 	Not a root to execute this script
#	3 	Command not found
#	4	Command failed for some reason
#

#
# Source the common commands and files script
#
SCRIPTDIR=`/usr/bin/dirname $0`
. ${SCRIPTDIR}/scm-agent-common.sh

#
# make sure this test is run as root
#
if [ "`$ID -un`" != "root" ] ; then
    $ECHO "You are not a root to execute this command\n" > "/dev/stderr"
    exit 2
fi

usage() {
    $ECHO "Usage: prj_add.sh -n <projectName> -p <projectID> -c <comment> -u <userlist> -g <grouplist> -r <resctls>" > "/dev/stderr"

   $ECHO "
      -n <projectname>	Name of the project to be modified
      -p <projectid>    Project ID
      -c <comment>	Comment associated with this project
      -u <userlist>	List of users for this project
      -g <grouplist> 	List of groups for this project
      -r <resctls>	Resource controls of this project
"
}

#
# check for sufficient input
#
# The script can be called with either the projectname and 
# projectid or just the projectname. The system will allocate 
# projectid. Since, there are chances that the projects get 
# deleted and the same project can be added with the same projectid, 
# this would have adverse effect on the extended accounting for 
# the current project (where, the system stores previous (same) 
# project/projectid's data also), hence, we have to make it 
# compulsory to pass the projectid of our own. The seahaven 
# would maintain a unique project id
#
if [ $# -lt 2 ]; then 
    usage
    exit 1
fi

# Set OS version
setSCMOSVersion

#
# Take the backup of the /etc/project file and the set
# the trap handler.
#
setTrap

#
# Make sure the projadd command exists
#
$PKGINFO -qi SUNWesu
if [ $? -ne 0 ] ; then
    $ECHO "SUNWesu: Extended System Utility pkg not installed\n" > "/dev/stderr"
    exit 3
fi

#
# make sure the accounting package is installed
#
$PKGINFO -qi SUNWcsu
if [ $? -ne 0 ] ; then
    $ECHO "Core Package: SUNWcsu not installed\n" > "/dev/stderr"
    exit 3
fi

GIVEN_PROJID=0
PROJNAME=""
COMMENT=""
USERS=""
GROUPS=""
RCTLS=""

while [ $# -gt 0 ]
do
    case $1 in
	-n) 
	     shift
	     PROJNAME=$1
	     shift
	     ;;
	-p)
	     shift
	     GIVEN_PROJID=$1
	     shift
	     ;;
        -c)  
	     shift
	     COMMENT=$1
	     shift
	     ;;
	-u)
	     shift
	     USERS=$1
	     shift
	     ;;
	-g)
	     shift
	     GROUPS=$1
	     shift
	     ;;
	-r)
	     shift
	     RCTLS=$1
	     shift
	     ;;
	-*)
	     usage
	     exit 1
	     ;;
	*)
	     if [ -z "$PROJNAME" ]; then
		 PROJNAME=$1
	     else
		 usage
		 exit 1
             fi
	     shift
	     ;;
    esac
done

#
# Now execute the projadd command
#
COMMAND="$PROJADD"
if [ $SCMOSVERS -ge 10 ]; then
    COMMAND="$PROJADD -n "
fi

if [ $GIVEN_PROJID -eq -1 ] ; then
    $COMMAND $PROJNAME 
else
    $COMMAND -p $GIVEN_PROJID $PROJNAME 
fi

#
# get the status of the above command execution
#
STATUS=$?
#
# Now get the project id to verify whether the given and 
# the one in /etc/project are the same
#
PROJ_ID="`$GREP ${PROJNAME}: $PROJECTFILE | \
	    $AWK -F: '{print $2}'`"

#
# Check exit status from command is correct
#
if [ $STATUS -ne 0 ] ; then
   $ECHO "$COMMAND $PROJNAME did not succeed\n"  > "/dev/stderr"
   exit 4
# Check project entry has been added to /etc/project
elif [ "`$EGREP \"^${PROJNAME}:\" $PROJECTFILE`" = "" ]; then
    $ECHO "$PROJNAME is not found in the /etc/project database\n" > "/dev/stderr"
    exit 4
# Check correct id has been assigned to project entry
elif [ $PROJ_ID -ne $GIVEN_PROJID ]; then
    $ECHO "$PROJID and $GIVEN_PROJID are not the same\n" > "/dev/stderr"
    exit 4
fi
#
# The project is successfully created.
# Now add the comments, groups, resource controls to it.
#

#
# Now execute the command. If the command fails due to insufficient information
# it will write an error to the stderr
#

if [ ! -z "$COMMENT" ]; then
   COMMAND="$PROJMOD -c"
   $COMMAND "$COMMENT" $PROJNAME 
fi

if [ ! -z "$USERS" ]; then
   COMMAND="$PROJMOD -U"
   $COMMAND "$USERS" $PROJNAME 
fi

if [ ! -z "$GROUPS" ]; then
   COMMAND="$PROJMOD -G"
   $COMMAND "$GROUPS" $PROJNAME 
fi

#
# Add the resource controls
#
if [ ! -z "$RCTLS" ]; then
    #
    # if the tmpProject present, delete it.
    #

    if [ -d $SCMTMPDIR ]; then
        if [ -x $SCMTMPPROJECTFILE ]; then
            $RM -rf $SCMTMPPROJECTFILE
        fi
    else
	$MKDIR $SCMTMPDIR
    fi

    projentry=`$GREP ${PROJNAME}: $PROJECTFILE` 
    #
    # Now add the resource controls to projentry
    #
    projentry=$projentry$RCTLS 
    $SED "/^${PROJNAME}:/d" $PROJECTFILE  > $SCMTMPPROJECTFILE
    $ECHO "$projentry" >> $SCMTMPPROJECTFILE
    $CP $SCMTMPPROJECTFILE $PROJECTFILE
    $RM -rf $SCMTMPPROJECTFILE
    $RM -rf $SCMTMPDIR
fi

exit 0
